FlexItemThemeData class
A class that defines the theme data for individual items in the FlexSidebar. This includes styling, padding, colors, and other visual properties.
Constructors
- FlexItemThemeData({TextStyle itemTextStyle = const TextStyle(fontSize: 20), EdgeInsetsDirectional iconPadding = const EdgeInsetsDirectional.fromSTEB(2, 0, 0, 0), EdgeInsetsDirectional labelPadding = const EdgeInsetsDirectional.fromSTEB(15, 0, 0, 0), EdgeInsetsDirectional itemPadding = const EdgeInsetsDirectional.fromSTEB(5, 10, 0, 10), Color hoverAnimColor = Colors.white70, Color itemColor = Colors.black45, Color selectedItemColor = Colors.black, Color disabledItemColor = Colors.black12, double? iconSize = 30})
-
Creates a
FlexItemThemeDatainstance with default or custom values.const
Properties
- disabledItemColor → Color
-
The color of the item when it is disabled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hoverAnimColor → Color
-
The color used for hover animations.
final
- iconPadding → EdgeInsetsDirectional
-
Padding around the item's icon.
final
- iconSize → double?
-
The size of the item's icon.
final
- itemColor → Color
-
The default color of the item.
final
- itemPadding → EdgeInsetsDirectional
-
Padding around the entire item.
final
- itemTextStyle → TextStyle
-
The text style for the item's label.
final
- labelPadding → EdgeInsetsDirectional
-
Padding around the item's label.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedItemColor → Color
-
The color of the item when it is selected.
final
Methods
-
copyWith(
{TextStyle? itemTextStyle, EdgeInsetsDirectional? iconPadding, EdgeInsetsDirectional? labelPadding, EdgeInsetsDirectional? itemPadding, Color? hoverAnimColor, Color? itemColor, Color? selectedItemColor, Color? disabledItemColor}) → FlexItemThemeData -
Creates a copy of the current
FlexItemThemeDatawith updated properties. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited